const _ = require('lodash');

module.exports = (actions) => {
	const dbAction = {
		create: false,
		find: false,
		count: false,
		list: false,
		insert: false,
		get: false,
		update: false,
		remove: false
	};
	const mongooseActions = {
		aggregate: {
			rest: false,
			handler: require('./actions/aggregate.action')
		},
		create: {
			rest: false,
			handler: require('./actions/create.action')
		},
		findOne: {
			rest: false,
			handler: require('./actions/findOne.action')
		},
		findMany: {
			rest: false,
			handler: require('./actions/find.action')
		},
		findOneAndUpdate: {
			rest: false,
			handler: require('./actions/findOneAndUpdate.action')
		},
		delete: {
			rest: false,
			handler: require('./actions/delete.action')
		},
		deleteMany: {
			rest: false,
			handler: require('./actions/deleteMany.action')
		},
		updateOne: {
			rest: false,
			handler: require('./actions/updateOne.action')
		},
		update: {
			rest: false,
			handler: require('./actions/update.action')
		},
		updateMany: {
			rest: false,
			handler: require('./actions/update.action')
		},
		findOneSecondary: {
			async handler(ctx) {
				const result = await this.adapter.model.findOne(...ctx.params).read('secondary').lean();
				return result;
			}
		},
		findManySecondary: {
			async handler(ctx) {
				const result = await this.adapter.model.find(...ctx.params).read('secondary').lean();
				return result;
			}
		},
		aggregateSecondary: {
			async handler(ctx) {
				const result = await this.adapter.model.aggregate(...ctx.params).read('secondary');
				return result;
			}
		},
		aggregateWithHint: {
			rest: false,
			handler: require('./actions/aggregateWithHint.action')
		}, 
		countRow: {
			rest: false,
			handler: require('./actions/count.action')
		},
		distinct: {
			rest: false,
			handler: require('./actions/distinct.action')
		}
	};
	_.forEach(mongooseActions, (v, k) => {
		dbAction[k] = v;
	});
	_.forEach(actions, (v, k) => {
		dbAction[k] = v;
	});
	return dbAction;
};
